Exception: Rollback
- Inherits:
-
StandardError
- Object
- StandardError
- Rollback
- Defined in:
- lib/sapis/sqlite_layer.rb
Overview
In block form, transaction don’t accept the :rollback call, so we need to use an exception.
In block form, transaction don’t accept the :rollback call, so we need to use an exception.